==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActivityDiagramActionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityDiagramAction;
import io.ciera.tool.sql.ooaofooa.activity.ActivityDiagramActionSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class ActivityDiagramActionSetImpl extends InstanceSet<ActivityDiagramActionSet,ActivityDiagramAction> implements ActivityDiagramActionSet {

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ActivityDiagramAction activitydiagramaction : this ) activitydiagramaction.setName( m_Name );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActivityDiagramAction activitydiagramaction : this ) activitydiagramaction.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ActivityDiagramAction activitydiagramaction : this ) activitydiagramaction.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public ActionNodeSet R1107_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( ActivityDiagramAction activitydiagramaction : this ) actionnodeset.add( activitydiagramaction.R1107_is_a_ActionNode() );
        return actionnodeset;
    }


    @Override
    public ActivityDiagramAction nullElement() {
        return ActivityDiagramActionImpl.EMPTY_ACTIVITYDIAGRAMACTION;
    }

    @Override
    public ActivityDiagramActionSet emptySet() {
      return new ActivityDiagramActionSetImpl();
    }

    @Override
    public ActivityDiagramActionSet value() {
        return this;
    }

    @Override
    public List<ActivityDiagramAction> elements() {
        ActivityDiagramAction[] elements = toArray(new ActivityDiagramAction[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActivityDiagramActionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityDiagramAction;
import io.ciera.tool.sql.ooaofooa.activity.ActivityDiagramActionSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ActivityDiagramActionSetImpl extends InstanceSet<ActivityDiagramActionSet,ActivityDiagramAction> implements ActivityDiagramActionSet {

    public ActivityDiagramActionSetImpl() {
    }

    public ActivityDiagramActionSetImpl(Comparator<? super ActivityDiagramAction> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActivityDiagramAction activitydiagramaction : this ) activitydiagramaction.setId( ref_Id );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ActivityDiagramAction activitydiagramaction : this ) activitydiagramaction.setName( m_Name );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ActivityDiagramAction activitydiagramaction : this ) activitydiagramaction.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public ActionNodeSet R1107_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( ActivityDiagramAction activitydiagramaction : this ) actionnodeset.add( activitydiagramaction.R1107_is_a_ActionNode() );
        return actionnodeset;
    }


    @Override
    public ActivityDiagramAction nullElement() {
        return ActivityDiagramActionImpl.EMPTY_ACTIVITYDIAGRAMACTION;
    }

    @Override
    public ActivityDiagramActionSet emptySet() {
      return new ActivityDiagramActionSetImpl();
    }

    @Override
    public ActivityDiagramActionSet emptySet(Comparator<? super ActivityDiagramAction> comp) {
      return new ActivityDiagramActionSetImpl(comp);
    }

    @Override
    public ActivityDiagramActionSet value() {
        return this;
    }

    @Override
    public List<ActivityDiagramAction> elements() {
        ActivityDiagramAction[] elements = toArray(new ActivityDiagramAction[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
